## Best Practices for Software Registries Task Force

This Task Force of the FORCE11 Software Citation Implementation Working Group is composed of managers and editors of scientific software registries and repositories. The Task Force identified nine best practices for software registries; these are listed below. Also listed below are policy examples as implemented by different registries or similar services.

More information on these practices is available in [Nine Best Practices for Research Software Registries and Repositories: A Concise Guide](https://arxiv.org/abs/2012.13117).

### Best practices

- Provide a public scope statement
- Provide guidance for users
- Provide guidance to software contributors
- Establish an authorship policy
- Share your metadata schema
- Stipulate conditions of use
- State a privacy policy
- Provide a retention policy
- Disclose your end-of-life policy

### Policy Examples

- **Scope Statement**
  - Astrophysics Source Code Library. (n.d.). Editorial policy. https://ascl.net/wordpress/submissions/editiorial-policy/
  - bio.tools. (n.d.). Curators Guide. https://biotools.readthedocs.io/en/latest/curators_guide.html
  - Caltech Library. (2017). Terms of Deposit. https://data.caltech.edu/terms
  - Caltech Library. (2019). CaltechDATA FAQ. Caltech Library. https://www.library.caltech.edu/caltechdata/faq
  - Computational Infrastructure for Geodynamics. (n.d.). Code Donation. https://geodynamics.org/cig/dev/code-donation/
  - CoMSES Net Computational Model Library. (n.d.). Frequently Asked Questions. https://www.comses.net/about/faq/#model-library
  - ORNL DAAC for Biogeochemical Dynamics. (n.d.). Data Scope and Acceptance Policy. https://daac.ornl.gov/submit/
  - RDA Registry and Research Data Australia. (2018). Collection. ARDC Intranet. https://intranet.ands.org.au/display/DOC/Collection
  - Remote Sensing Code Library. (n.d.). Submit. https://rscl-grss.org/submit.php
  - SciCrunch. (n.d.). Curation Guide for SciCrunch Registry. https://scicrunch.org/page/Curation%20Guidelines
  - U.S. Department of Energy: Office of Scientific and Technical Information. (n.d.-a). DOE CODE: Software Policy. https://www.osti.gov/doecode/policy
  - U.S. Department of Energy: Office of Scientific and Technical Information. (n.d.-b). FAQs. OSTI.GOV. https://www.osti.gov/faqs

- **Authorship**
  - CASRAI. (n.d.). CRediT - Contributor Roles Taxonomy. CASRAI. https://casrai.org/credit/
  - Committee on Publication Ethics: COPE. (2020a). Authorship and contributorship. https://publicationethics.org/authorship
  - Committee on Publication Ethics: COPE. (2020b). Core practices. https://publicationethics.org/core-practices
  - Dagstuhl EAS Specification Draft. (2016). The Software Credit Ontology. https://dagstuhleas.github.io/SoftwareCreditRoles/doc/index-en.html
  - Journal of Open Source Software. (n.d.). Ethics Guidelines. https://joss.theoj.org/about\#ethics
  - ORNL DAAC (n.d) Authorship Policy. https://daac.ornl.gov/submit/
  - PeerJ Journals. (n.d.-a). Author Policies. https://peerj.com/about/policies-and-procedures/#author-policies
  - PeerJ Journals. (n.d.-b). Publication Ethics. https://peerj.com/about/policies-and-procedures/#publication-ethics
  - PLOS ONE. (n.d.). Authorship. https://journals.plos.org/plosone/s/authorship
  - National Center for Data to Health. (2019). The Contributor Role Ontology. https://github.com/data2health/contributor-role-ontology

- **Metadata Schema**
  - ANDS: Australian National Data Service. (n.d.). Metadata. ANDS. https://www.ands.org.au/working-with-data/metadata
  - ANDS: Australian National Data Service. (2016). ANDS Guide: Metadata. https://www.ands.org.au/__data/assets/pdf_file/0004/728041/Metadata-Workinglevel.pdf
  - Bernal, I. (2019). Metadata for Data Repositories. https://doi.org/10.5281/zenodo.3233486
  - bio.tools. (2020). Bio-tools/biotoolsSchema. https://github.com/bio-tools/biotoolsSchema
  - bio.tools. (2019). BiotoolsSchema documentation. https://biotoolsschema.readthedocs.io/en/latest/
  - The CodeMeta crosswalks. (n.d.) https://codemeta.github.io/crosswalk/
  - Citation File Format (CFF). (n.d.) https://doi.org/10.5281/zenodo.1003149
  - The DataVerse Project. (2020). DataVerse 4.0+ Metadata Crosswalk. https://docs.google.com/spreadsheets/d/10Luzti7svVTVKTA-px27oq3RxCUM-QbiTkm8iMd5C54
  - OntoSoft. (2015). OntoSoft Ontology. https://ontosoft.org/ontology/software/
  - OpenAPI Specification. (2020). http://spec.openapis.org/oas/v3.0.3
  - Zenodo. (n.d.-a). Schema for Depositing. https://zenodo.org/schemas/records/record-v1.0.0.json
  - Zenodo. (n.d.-b). Schema for Published Record. https://zenodo.org/schemas/deposits/records/legacyrecord.json

- **Conditions of use policy**
  - Allen Institute. (n.d.). Terms of Use. https://alleninstitute.org/legal/terms-use/
  - Europeana. (n.d.). Usage Guidelines for Metadata. Europeana Collections. https://www.europeana.eu/portal/en/rights/metadata.html
  - U.S. Department of Energy: Office of Scientific and Technical Information. (n.d.). DOE CODE FAQ: Are there restrictions on the use of the material in DOE CODE? https://www.osti.gov/doecode/faq\#are-there-restrictions
  - Zenodo. (n.d.). Terms of Use. https://about.zenodo.org/terms/

- **Privacy policy**
  - Allen Institute. (n.d.). Privacy Policy. https://alleninstitute.org/legal/privacy-policy/
  - CoMSES Net. (n.d.). Data Privacy Policy. https://www.comses.net/about/data-privacy/
  - Nature. (2020). Privacy Policy. https://www.nature.com/info/privacy
  - Research Data Australia. (n.d.). Privacy Policy. Research Data Australia. https://researchdata.ands.org.au/page/privacy
  - SciCrunch. (2018). Privacy Policy. SciCrunch. https://scicrunch.org/page/privacy
  - Science Repository. (n.d.). Privacy Policies. https://www.sciencerepository.org/privacy
  - Zenodo. (n.d.). Privacy policy. https://about.zenodo.org/privacy-policy/

- **Retention Policy**
  - Caltech Library. (n.d.). CaltechDATA FAQ. https://www.library.caltech.edu/caltechdata/faq
  - CoMSES Net Computational Model Library. (n.d.). How long will models be stored in the Computational Model Library? https://www.comses.net/about/faq/
  - Dryad. (2020). Dryad FAQ - Publish and Preserve your Data. https://datadryad.org/stash/faq\#preserved
  - Software Heritage. (n.d.). Content policy. https://www.softwareheritage.org/legal/content-policy/
  - Zenodo. (n.d.). General Policies v1.0. https://about.zenodo.org/policies/

- **End-of-life policy**
  - Bioconductor. (2020). Package End of Life Policy. https://bioconductor.org/developers/package-end-of-life/ 
  - Figshare. (n.d.). Preservation and Continuity of Access Policy. https://knowledge.figshare.com/articles/item/preservation-and-continuity-of-access-policy
  - Open Science Framework. (2019). FAQs. OSF Guides. http://help.osf.io/hc/en-us/articles/360019737894-FAQs
  - NASA Earth Science Data Preservation Content Specification (n.d.) https://earthdata.nasa.gov/esdis/eso/standards-and-references/preservation-content-spec
  - Zenodo. (n.d.). Frequently Asked Questions. https://help.zenodo.org/
