_Comments and suggestions on this document can be added to the Google Doc version here: https://docs.google.com/document/d/1Puj13cdJXm5RO4ycWJz8f7Eo-nKwHA4NIKQ-jSgaTVU/edit#heading=h.44hhurazoaq6 or via a GitHub issue_

# Why is it so important to cite software?

Books and journal articles have long benefited from an infrastructure that makes them easy to cite, a key element in the process of research and academic discourse. We believe that you should cite software (including code, scripts, notebooks and libraries) in the same way that you cite other sources of information, such as articles and books.

Citing software helps further research and improves access to research software in order to:

  - support proper attribution and credit
  - support collaboration and reuse
  - enable reproducibility of findings
  - encourage building on the work of others, and
  - provide the means to share software and data with future researchers

FORCE11 has been developing guidance for software citation. The Software Citation Principles (Smith et al 2016) were written to encourage broad adoption of a consistent policy for software citation across disciplines and venues. The Software Citation Checklist for Authors (Chue Hong et al. 2019a) and Software Citation Checklist for Developers (Chue Hong et al. 2019b) provide more practical information for those seeking to improve their practice.

## Software Citation Essentials

We recognise that the challenges associated with software deposit and publication vary across disciplines, and we encourage research communities to develop citation systems that work well for them. We also recognise that the citation style formats used vary between disciplines and journals.

```diff
+ comment from Telli Faez: if a software paper exists, should cite it; if not, do the following
+ response from Dan: goal is to cite software itself; if a software paper exists, can cite it too
```

Our recommended format for software citation is to ensure the following information is provided as part of the reference:

  - Creator: the authors or project that developed the software
  - Title: the name of the software
  - Identifier: a resolvable pointer to the software

Ideally, the identifier would be a persistent pointer to a landing page containing descriptive metadata about the software, similar to a DOI for a paper that points to a page about the paper rather than directly to the PDF.

It may also be desirable to include information about three optional properties (as appropriate):

  - Date: the date the software was created or published.
  - Version: the identifier for the version of the software being referenced.
  - Publisher: the repository publishing the software. 

### Software Citation Examples

APA style: 
```diff
+ comment from Matt Cannon: FT&F production team say APA reference style was updated at the end of
+ 2019, and we should update the examples to be correct in the latest version of APA style. Looking
+ at the information in the new guide they do include a section on how to cite software (10.10).
```

 - Amet Corp. _Ametcon [Computer software]_. Retrieved from http://ametcon.com
 - L1psum Project. (2016). _L1psum_. Retrieved from: https://github.com/l1psum/l1psum
 - Researcher, A. (2019). _Dolorsit_, v1.0. Zenodo, doi:10.5281/zenodo.O12345

```diff
+ comment from Matt Cannon: FT&F production team suggested that as the Chicago reference style
+ offers “suggestions” rather than “rules”, they thought adopting a different style might be best
+ if we want to give very clear examples.
```

Chicago style:
 - Amet Corp. "Ametcon." http://ametcon.com
 - L1psum Project. 2016. "L1psum." Retrieved from: https://github.com/l1psum/l1psum
 - Researcher, A. 2019. "Dolorsit, v1.0." _Zenodo_. doi:10.5281/zenodo.O12345


<HR>

### Acknowledgements

This article is based on data citation guidance published by DataCite (Datacite).
It was initially drafted by Neil Chue Hong, and Daniel S. Katz provided feedback leading to a revised version.

### References

  - Chue Hong, Neil P., Allen, Alice, Gonzalez-Beltran, Alejandra, de Waard, Anita, Smith, Arfon M., Robinson, Carly, … Pollard, Tom. (2019, October 15). Software Citation Checklist for Authors (Version 0.9.0). Zenodo. http://doi.org/10.5281/zenodo.3479199
  - Chue Hong, Neil P., Allen, Alice, Gonzalez-Beltran, Alejandra, de Waard, Anita, Smith, Arfon M., Robinson, Carly, … Pollard, Tom. (2019, October 15). Software Citation Checklist for Developers (Version 0.9.0). Zenodo. http://doi.org/10.5281/zenodo.3482769
  - DataCite. DataCite - Cite Your Data. https://datacite.org/cite-your-data.html
  - Smith AM, Katz DS, Niemeyer KE, FORCE11 Software Citation Working Group.
(2016) Software Citation Principles. PeerJ Computer Science 2:e86.
DOI: [10.7717/peerj-cs.86](https://doi.org/10.7717/peerj-cs.86)
